# usage:
#        > gnuplot
# gnuplot> call 'mcc.gp' 'inputData.dat' 'outputFile.pdf'
#
#######################################################################
#   HA graphs
#######################################################################
rad2as = 2.0626480624709635e5
tacv2as = 596.8310658
#
set term postscript portrait color solid 07
set output "mcc_ha.ps"
set size 1.0, 1.0
set origin 0.0, 0.0
set multiplot
set style data lines

# plot Position
set size 1.00,0.20
set origin 0.0,0.80
set title "HA Position $0 " 
set xlabel "Seconds"
set ylabel "ArcSeconds"
plot "$0" using 1:($$15*rad2as) title "m_dpos",\
     "$0" using 1:($$17*rad2as) title "m_apos"

# plot Velocity #
set size 1.00,0.20
set origin 0.0,0.60
set title "HA Velocity"
set xlabel "Seconds"
set ylabel "ArcSec/sec"
#set yrange [-10:10]
plot "$0" using 1:($$19*rad2as) title "m_avel", \
     "$0" using 1:($$23*tacv2as) title "tac"

# plot Following Error #
set size 1.00,0.20
set origin 0.0,0.4
set title "HA Following Error"
set xlabel "Seconds"
set ylabel "ArcSeconds"
#set yrange [-1:1]
plot "$0" using 1:(($$15 - $$17)*rad2as) title "Motor"

# plot DAC Values #
set size 1.00,0.20
set origin 0.0,0.2
set title "West DAC "
set xlabel "Seconds"
set ylabel "Volts"
plot "$0" using 1:($$25) title "West"

set size 1.00,0.20
set origin 0.0,0.0
set title "East DAC"
set xlabel "Seconds"
set ylabel "Volts"
plot "$0" using 1:($$26) title "East"


unset multiplot

#######################################################################
#   Dec graphs
#######################################################################
#
rad2as = 2.0626480624709635e5
#
set term postscript portrait color solid 07
set output "mcc_dec.ps"
set size 1.0, 1.0
set origin 0.0, 0.0
set multiplot
set style data lines

# plot Position
set size 1.00,0.20
set origin 0.0,0.80
set title "Dec Position $0 "
set xlabel "Seconds"
set ylabel "ArcSeconds"
plot "$0" using 1:($$16*rad2as) title "m_dpos",\
     "$0" using 1:($$18*rad2as) title "m_apos"

# plot Velocity #
set size 1.00,0.20
set origin 0.0,0.60
set title "Dec Velocity"
set xlabel "Seconds"
set ylabel "ArcSec/sec"
#set yrange [-10:10]
plot "$0" using 1:($$20*rad2as) title "Motor", \
     "$0" using 1:($$24*tacv2as) title "tac"

# plot Following Error #
set size 1.00,0.20
set origin 0.0,0.4
set title "Dec Following Error"
set xlabel "Seconds"
set ylabel "ArcSeconds"
plot "$0" using 1:(($$16 - $$18)*rad2as) title "Motor"

# plot DAC Values #
set size 1.00,0.20
set origin 0.0,0.2
set title "North DAC"
set xlabel "Seconds"
set ylabel "Volts"
plot "$0" using 1:($$27) title "North"

# plot TAC Values
set size 1.00,0.20
set origin 0.0,0.0
set title "South DAC"
set xlabel "Seconds"
set ylabel "Volts"
plot "$0" using 1:($$28) title "South"

unset multiplot

#######################################################################
#   motor current graphs
#######################################################################
#
#
set term postscript portrait color solid 07
set output "currents.ps"
set size 1.0, 1.0
set origin 0.0, 0.0
set multiplot
set style data lines

# HA motor currents
set size 1.00,0.20
set origin 0.0,0.80
set title "HA currents"
set xlabel "Seconds"
set ylabel "Current (volts * 11.66)"
plot "$0" using 1:29  title "East",\
     "$0" using 1:30  title "West"

# Dec motor currents
set size 1.00,0.20
set origin 0.0,0.60
set title "Dec currents"
set xlabel "Seconds"
set ylabel "Current (volts * 11.66)"
plot "$0" using 1:31  title "North",\
     "$0" using 1:32  title "South"

# Dome motor currents
#set size 1.00,0.20
#set origin 0.0,0.40
#set title "Dome currents"
#set xlabel "Seconds"
#set ylabel "Current (volts * 11.66)"
#plot "$0" using 1:33  title "Dome1",\
#     "$0" using 1:34  title "Dome2",\
#     "$0" using 1:35  title "Dome3"
#
unset multiplot

#########################################################333
##  Merge ps files & convert to pdf.
#########################################################333

! exec gs -dNOPAUSE -sDEVICE=pdfwrite -sOUTPUTFILE="$1" -dBATCH mcc_ha.ps mcc_dec.ps currents.ps
! rm mcc_ha.ps mcc_dec.ps currents.ps
